pub struct ProgressDispatcher { /* private fields */ }Available on crate feature
client only.Expand description
A dispatcher for progress notifications.
Implementations
Sourceimpl ProgressDispatcher
impl ProgressDispatcher
pub fn new() -> Self
Sourcepub async fn handle_notification(&self, notification: ProgressNotificationParam)
pub async fn handle_notification(&self, notification: ProgressNotificationParam)
Handle a progress notification by sending it to the appropriate subscriber
Sourcepub async fn subscribe(
&self,
progress_token: ProgressToken,
) -> ProgressSubscriber
pub async fn subscribe( &self, progress_token: ProgressToken, ) -> ProgressSubscriber
Subscribe to progress notifications for a specific token.
If you drop the returned ProgressSubscriber, it will automatically unsubscribe from notifications for that token.
Sourcepub async fn unsubscribe(&self, token: &ProgressToken)
pub async fn unsubscribe(&self, token: &ProgressToken)
Unsubscribe from progress notifications for a specific token.