ContextInclusion

Enum ContextInclusion 

pub enum ContextInclusion {
    AllServers,
    None,
    ThisServer,
}
Specifies how much context should be included in sampling requests.

This allows clients to control what additional context information should be provided to the LLM when processing sampling requests.

Variants



AllServers

Include context from all connected MCP servers



None

Include no additional context



ThisServer

Include context only from the requesting server