pub enum PromptMessageContent {
Text {
text: String,
},
Image {
image: ImageContent,
},
Resource {
resource: EmbeddedResource,
},
ResourceLink {
link: Resource,
},
}Expand description
Content types that can be included in prompt messages
Variants
Text
Plain text content
Image
Image content with base64-encoded data
Fields

image: ImageContentResource
Embedded server-side resource
Fields

resource: EmbeddedResourceResourceLink
A link to a resource that can be fetched separately
Implementations