pub enum TaskSupport {
Forbidden,
Optional,
Required,
}Expand description
Per-tool task support mode as defined in the MCP specification.
This enum indicates whether a tool supports task-based invocation, allowing clients to know how to properly call the tool.
Variants
Forbidden
Clients MUST NOT invoke this tool as a task (default behavior).
Optional
Clients MAY invoke this tool as either a task or a normal call.
Required
Clients MUST invoke this tool as a task.