pub fn object(value: Value) -> JsonObjectExpand description
unwrap the JsonObject under serde_json::Value
Panic
This will panic when the value is not a object in debug mode.
pub fn object(value: Value) -> JsonObjectunwrap the JsonObject under serde_json::Value
This will panic when the value is not a object in debug mode.