pub struct ArrayTypeConst;Trait Implementations
Sourceimpl Clone for ArrayTypeConst
impl Clone for ArrayTypeConst
Sourcefn clone(&self) -> ArrayTypeConst
fn clone(&self) -> ArrayTypeConst
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstString for ArrayTypeConst
impl ConstString for ArrayTypeConst
Sourceimpl Debug for ArrayTypeConst
impl Debug for ArrayTypeConst
Sourceimpl Default for ArrayTypeConst
impl Default for ArrayTypeConst
Sourcefn default() -> ArrayTypeConst
fn default() -> ArrayTypeConst
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ArrayTypeConst
impl<'de> Deserialize<'de> for ArrayTypeConst
Sourcefn deserialize<D>(deserializer: D) -> Result<ArrayTypeConst, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<ArrayTypeConst, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArrayTypeConst
Available on crate feature schemars only.
impl JsonSchema for ArrayTypeConst
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArrayTypeConst
impl PartialEq for ArrayTypeConst
Sourcefn eq(&self, other: &ArrayTypeConst) -> bool
fn eq(&self, other: &ArrayTypeConst) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ArrayTypeConst
impl Serialize for ArrayTypeConst
impl Copy for ArrayTypeConst
impl Eq for ArrayTypeConst
impl StructuralPartialEq for ArrayTypeConst