#[non_exhaustive]pub struct CreateMessageResult {
pub model: String,
pub stop_reason: Option<String>,
pub message: SamplingMessage,
}Expand description
Result of sampling/createMessage (SEP-1577). The result of a sampling/createMessage request containing the generated response.
This structure contains the generated message along with metadata about how the generation was performed and why it stopped.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model: StringThe identifier of the model that generated the response
stop_reason: Option<String>The reason why generation stopped (e.g., “endTurn”, “maxTokens”)
message: SamplingMessageThe generated message with role and content
Implementations
Sourceimpl CreateMessageResult
impl CreateMessageResult
pub const STOP_REASON_END_TURN: &str = "endTurn"
pub const STOP_REASON_END_SEQUENCE: &str = "stopSequence"
pub const STOP_REASON_END_MAX_TOKEN: &str = "maxTokens"
pub const STOP_REASON_TOOL_USE: &str = "toolUse"
Sourcepub fn new(message: SamplingMessage, model: String) -> Self
pub fn new(message: SamplingMessage, model: String) -> Self
Create a new CreateMessageResult with required fields.
Sourcepub fn with_stop_reason(self, stop_reason: impl Into<String>) -> Self
pub fn with_stop_reason(self, stop_reason: impl Into<String>) -> Self
Set the stop reason.
Sourcepub fn with_model(self, model: impl Into<String>) -> Self
pub fn with_model(self, model: impl Into<String>) -> Self
Set the model identifier.