#[non_exhaustive]pub struct CreateTaskResult {
pub result_type: ResultType,
pub task: Task,
pub meta: Option<MetaObject>,
}Expand description
Result returned in lieu of a standard result to indicate the request will
be processed asynchronously (spec CreateTaskResult, resultType: "task").
The embedded task is the seed state for the task; the client uses
task.task_id for all subsequent tasks/get, tasks/update, and
tasks/cancel calls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.result_type: ResultTypeAlways "task".
task: TaskSeed state of the newly created task, flattened at the top level.
meta: Option<MetaObject>Implementations