CustomRequest

Struct CustomRequest 

pub struct CustomRequest {
    pub method: String,
    pub params: Option<Value>,
    pub extensions: Extensions,
}
A catch-all request either side can use to send custom messages to its peer.

This preserves the raw method name and params payload so handlers can deserialize them into domain-specific types.

Fields

method: Stringparams: Option<Value>extensions: Extensions

extensions will carry anything possible in the context, including the metadata (RequestMetaObject for requests, NotificationMetaObject for notifications)

this is similar with the Extensions in http crate

Implementations

Source

impl CustomRequest

pub fn new(method: impl Into<String>, params: Option<Value>) -> Self

pub fn params_as<T: DeserializeOwned>(&self) -> Result<Option<T>, Error>

Deserialize params into a strongly-typed structure.