#[non_exhaustive]pub struct DiscoverResult {
pub result_type: ResultType,
pub supported_versions: Vec<ProtocolVersion>,
pub capabilities: ServerCapabilities,
pub instructions: Option<String>,
pub ttl_ms: u64,
pub cache_scope: CacheScope,
pub meta: Option<MetaObject>,
}Expand description
The server’s response to a DiscoverRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.result_type: ResultTypeIdentifies how the result should be parsed.
supported_versions: Vec<ProtocolVersion>Protocol versions implemented by this server.
capabilities: ServerCapabilitiesCapabilities provided by this server.
instructions: Option<String>Optional guidance for using the server.
ttl_ms: u64How long clients may consider this response fresh, in milliseconds.
cache_scope: CacheScopeWhether the cached result may be shared across authorization contexts.
meta: Option<MetaObject>Protocol-level response metadata.
Implementations
Sourceimpl DiscoverResult
impl DiscoverResult
Sourcepub fn new(
supported_versions: Vec<ProtocolVersion>,
capabilities: ServerCapabilities,
) -> Self
pub fn new( supported_versions: Vec<ProtocolVersion>, capabilities: ServerCapabilities, ) -> Self
Create a non-cacheable private discovery result.
Sourcepub fn server_info(&self) -> Option<Implementation>
pub fn server_info(&self) -> Option<Implementation>
Return the server implementation information stored in result metadata.
Sourcepub fn set_server_info(&mut self, server_info: Implementation)
pub fn set_server_info(&mut self, server_info: Implementation)
Store server implementation information in result metadata.
Sourcepub fn with_server_info(self, server_info: Implementation) -> Self
pub fn with_server_info(self, server_info: Implementation) -> Self
Store server implementation information in result metadata.
Sourcepub fn from_server_info(
supported_versions: Vec<ProtocolVersion>,
server_info: ServerInfo,
) -> Self
pub fn from_server_info( supported_versions: Vec<ProtocolVersion>, server_info: ServerInfo, ) -> Self
Create a discovery result from the server’s initialization information.
Sourcepub fn with_ttl_ms(self, ttl_ms: u64) -> Self
pub fn with_ttl_ms(self, ttl_ms: u64) -> Self
Set the cache lifetime hint in milliseconds.
Sourcepub fn with_cache_scope(self, cache_scope: CacheScope) -> Self
pub fn with_cache_scope(self, cache_scope: CacheScope) -> Self
Set the cache scope.