pub struct ElicitationCompletionNotificationMethod;Trait Implementations
Sourceimpl Clone for ElicitationCompletionNotificationMethod
impl Clone for ElicitationCompletionNotificationMethod
Sourcefn clone(&self) -> ElicitationCompletionNotificationMethod
fn clone(&self) -> ElicitationCompletionNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ElicitationCompletionNotificationMethod
Sourceimpl Default for ElicitationCompletionNotificationMethod
impl Default for ElicitationCompletionNotificationMethod
Sourcefn default() -> ElicitationCompletionNotificationMethod
fn default() -> ElicitationCompletionNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ElicitationCompletionNotificationMethod
impl<'de> Deserialize<'de> for ElicitationCompletionNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ElicitationCompletionNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ElicitationCompletionNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ElicitationCompletionNotificationMethod
Sourceimpl JsonSchema for ElicitationCompletionNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for ElicitationCompletionNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ElicitationCompletionNotificationMethod
impl PartialEq for ElicitationCompletionNotificationMethod
Sourcefn eq(&self, other: &ElicitationCompletionNotificationMethod) -> bool
fn eq(&self, other: &ElicitationCompletionNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ElicitationCompletionNotificationMethod