pub struct GetTaskMethod;Trait Implementations
Sourceimpl Clone for GetTaskMethod
impl Clone for GetTaskMethod
Sourcefn clone(&self) -> GetTaskMethod
fn clone(&self) -> GetTaskMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstString for GetTaskMethod
impl ConstString for GetTaskMethod
impl Copy for GetTaskMethod
Sourceimpl Debug for GetTaskMethod
impl Debug for GetTaskMethod
Sourceimpl Default for GetTaskMethod
impl Default for GetTaskMethod
Sourcefn default() -> GetTaskMethod
fn default() -> GetTaskMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetTaskMethod
impl<'de> Deserialize<'de> for GetTaskMethod
Sourcefn deserialize<D>(deserializer: D) -> Result<GetTaskMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<GetTaskMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GetTaskMethod
Sourceimpl JsonSchema for GetTaskMethod
Available on crate feature schemars only.
impl JsonSchema for GetTaskMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetTaskMethod
impl PartialEq for GetTaskMethod
Sourcefn eq(&self, other: &GetTaskMethod) -> bool
fn eq(&self, other: &GetTaskMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetTaskMethod
impl Serialize for GetTaskMethod
impl StructuralPartialEq for GetTaskMethod