pub struct GetTaskPayloadMethod;Trait Implementations
Sourceimpl Clone for GetTaskPayloadMethod
impl Clone for GetTaskPayloadMethod
Sourcefn clone(&self) -> GetTaskPayloadMethod
fn clone(&self) -> GetTaskPayloadMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstString for GetTaskPayloadMethod
impl ConstString for GetTaskPayloadMethod
impl Copy for GetTaskPayloadMethod
Sourceimpl Debug for GetTaskPayloadMethod
impl Debug for GetTaskPayloadMethod
Sourceimpl Default for GetTaskPayloadMethod
impl Default for GetTaskPayloadMethod
Sourcefn default() -> GetTaskPayloadMethod
fn default() -> GetTaskPayloadMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetTaskPayloadMethod
impl<'de> Deserialize<'de> for GetTaskPayloadMethod
Sourcefn deserialize<D>(deserializer: D) -> Result<GetTaskPayloadMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<GetTaskPayloadMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GetTaskPayloadMethod
Sourceimpl JsonSchema for GetTaskPayloadMethod
Available on crate feature schemars only.
impl JsonSchema for GetTaskPayloadMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetTaskPayloadMethod
impl PartialEq for GetTaskPayloadMethod
Sourcefn eq(&self, other: &GetTaskPayloadMethod) -> bool
fn eq(&self, other: &GetTaskPayloadMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetTaskPayloadMethod
impl Serialize for GetTaskPayloadMethod
impl StructuralPartialEq for GetTaskPayloadMethod