pub struct JsonRpcNotification<N = Notification> {
pub jsonrpc: JsonRpcVersion2_0,
pub notification: N,
}Fields
jsonrpc: JsonRpcVersion2_0notification: NTrait Implementations
Sourceimpl<N: Clone> Clone for JsonRpcNotification<N>
impl<N: Clone> Clone for JsonRpcNotification<N>
Sourcefn clone(&self) -> JsonRpcNotification<N>
fn clone(&self) -> JsonRpcNotification<N>
Returns a duplicate of the value. Read more
1.0.0 · Sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<N: Debug> Debug for JsonRpcNotification<N>
impl<N: Debug> Debug for JsonRpcNotification<N>
Sourceimpl<'de, N> Deserialize<'de> for JsonRpcNotification<N>where
N: Deserialize<'de>,
impl<'de, N> Deserialize<'de> for JsonRpcNotification<N>where
N: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<N: JsonSchema> JsonSchema for JsonRpcNotification<N>
impl<N: JsonSchema> JsonSchema for JsonRpcNotification<N>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<N: PartialEq> PartialEq for JsonRpcNotification<N>
impl<N: PartialEq> PartialEq for JsonRpcNotification<N>
Sourcefn eq(&self, other: &JsonRpcNotification<N>) -> bool
fn eq(&self, other: &JsonRpcNotification<N>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<N> Serialize for JsonRpcNotification<N>where
N: Serialize,
impl<N> Serialize for JsonRpcNotification<N>where
N: Serialize,
impl<N> StructuralPartialEq for JsonRpcNotification<N>