pub struct JsonRpcResponse<R = JsonObject> {
pub jsonrpc: JsonRpcVersion2_0,
pub id: RequestId,
pub result: R,
}Fields
jsonrpc: JsonRpcVersion2_0id: RequestIdresult: RTrait Implementations
Sourceimpl<R: Clone> Clone for JsonRpcResponse<R>
impl<R: Clone> Clone for JsonRpcResponse<R>
Sourcefn clone(&self) -> JsonRpcResponse<R>
fn clone(&self) -> JsonRpcResponse<R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<R: Debug> Debug for JsonRpcResponse<R>
impl<R: Debug> Debug for JsonRpcResponse<R>
Sourceimpl<'de, R> Deserialize<'de> for JsonRpcResponse<R>where
R: Deserialize<'de>,
impl<'de, R> Deserialize<'de> for JsonRpcResponse<R>where
R: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<R> JsonSchema for JsonRpcResponse<R>where
R: JsonSchema,
impl<R> JsonSchema for JsonRpcResponse<R>where
R: JsonSchema,
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl<R: PartialEq> PartialEq for JsonRpcResponse<R>
impl<R: PartialEq> PartialEq for JsonRpcResponse<R>
Sourceimpl<R> Serialize for JsonRpcResponse<R>where
R: Serialize,
impl<R> Serialize for JsonRpcResponse<R>where
R: Serialize,
impl<R> StructuralPartialEq for JsonRpcResponse<R>