pub struct LegacyEnumSchema {
pub type_: StringTypeConst,
pub title: Option<Cow<'static, str>>,
pub description: Option<Cow<'static, str>>,
pub enum_: Vec<String>,
pub enum_names: Option<Vec<String>>,
}Expand description
Legacy enum schema, keep for backward compatibility
Fields
type_: StringTypeConsttitle: Option<Cow<'static, str>>description: Option<Cow<'static, str>>enum_: Vec<String>enum_names: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for LegacyEnumSchema
impl Clone for LegacyEnumSchema
Sourcefn clone(&self) -> LegacyEnumSchema
fn clone(&self) -> LegacyEnumSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LegacyEnumSchema
impl Debug for LegacyEnumSchema
Sourceimpl<'de> Deserialize<'de> for LegacyEnumSchema
impl<'de> Deserialize<'de> for LegacyEnumSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LegacyEnumSchema
impl JsonSchema for LegacyEnumSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LegacyEnumSchema
impl PartialEq for LegacyEnumSchema
Sourcefn eq(&self, other: &LegacyEnumSchema) -> bool
fn eq(&self, other: &LegacyEnumSchema) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LegacyEnumSchema
impl Serialize for LegacyEnumSchema
impl StructuralPartialEq for LegacyEnumSchema