pub struct ListRootsResult {
pub roots: Vec<Root>,
}Fields
roots: Vec<Root>Trait Implementations
Sourceimpl Clone for ListRootsResult
impl Clone for ListRootsResult
Sourcefn clone(&self) -> ListRootsResult
fn clone(&self) -> ListRootsResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRootsResult
impl Debug for ListRootsResult
Sourceimpl Default for ListRootsResult
impl Default for ListRootsResult
Sourcefn default() -> ListRootsResult
fn default() -> ListRootsResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ListRootsResult
impl<'de> Deserialize<'de> for ListRootsResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ListRootsResult> for ClientResult
impl From<ListRootsResult> for ClientResult
Sourcefn from(value: ListRootsResult) -> Self
fn from(value: ListRootsResult) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ListRootsResult
impl JsonSchema for ListRootsResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListRootsResult
impl PartialEq for ListRootsResult
Sourceimpl Serialize for ListRootsResult
impl Serialize for ListRootsResult
impl StructuralPartialEq for ListRootsResult