pub struct ObjectTypeConst;Trait Implementations
Sourceimpl Clone for ObjectTypeConst
impl Clone for ObjectTypeConst
Sourcefn clone(&self) -> ObjectTypeConst
fn clone(&self) -> ObjectTypeConst
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstString for ObjectTypeConst
impl ConstString for ObjectTypeConst
impl Copy for ObjectTypeConst
Sourceimpl Debug for ObjectTypeConst
impl Debug for ObjectTypeConst
Sourceimpl Default for ObjectTypeConst
impl Default for ObjectTypeConst
Sourcefn default() -> ObjectTypeConst
fn default() -> ObjectTypeConst
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ObjectTypeConst
impl<'de> Deserialize<'de> for ObjectTypeConst
Sourcefn deserialize<D>(deserializer: D) -> Result<ObjectTypeConst, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<ObjectTypeConst, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObjectTypeConst
Sourceimpl JsonSchema for ObjectTypeConst
Available on crate feature schemars only.
impl JsonSchema for ObjectTypeConst
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObjectTypeConst
impl PartialEq for ObjectTypeConst
Sourcefn eq(&self, other: &ObjectTypeConst) -> bool
fn eq(&self, other: &ObjectTypeConst) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObjectTypeConst
impl Serialize for ObjectTypeConst
impl StructuralPartialEq for ObjectTypeConst