pub struct ProgressToken(pub NumberOrString);Expand description
A token used to track the progress of long-running operations.
Progress tokens allow clients and servers to associate progress notifications with specific requests, enabling real-time updates on operation status.
Tuple Fields
0: NumberOrStringTrait Implementations
Sourceimpl Clone for ProgressToken
impl Clone for ProgressToken
Sourcefn clone(&self) -> ProgressToken
fn clone(&self) -> ProgressToken
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressToken
impl Debug for ProgressToken
Sourceimpl<'de> Deserialize<'de> for ProgressToken
impl<'de> Deserialize<'de> for ProgressToken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ProgressToken
impl Hash for ProgressToken
Sourceimpl JsonSchema for ProgressToken
impl JsonSchema for ProgressToken
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressToken
impl PartialEq for ProgressToken
Sourceimpl Serialize for ProgressToken
impl Serialize for ProgressToken
impl Eq for ProgressToken
impl StructuralPartialEq for ProgressToken