#[non_exhaustive]pub struct PromptArgument {
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub required: Option<bool>,
}Expand description
Represents a prompt argument that can be passed to customize the prompt
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the argument
title: Option<String>A human-readable title for the argument
description: Option<String>A description of what the argument is used for
required: Option<bool>Whether this argument is required
Implementations
Sourceimpl PromptArgument
impl PromptArgument
Sourcepub fn with_title<T: Into<String>>(self, title: T) -> Self
pub fn with_title<T: Into<String>>(self, title: T) -> Self
Set the title
Sourcepub fn with_description<D: Into<String>>(self, description: D) -> Self
pub fn with_description<D: Into<String>>(self, description: D) -> Self
Set the description
Sourcepub fn with_required(self, required: bool) -> Self
pub fn with_required(self, required: bool) -> Self
Set the required flag