RawResource

Struct RawResource 

pub struct RawResource {
    pub uri: String,
    pub name: String,
    pub title: Option<String>,
    pub description: Option<String>,
    pub mime_type: Option<String>,
    pub size: Option<u32>,
    pub icons: Option<Vec<Icon>>,
    pub meta: Option<Meta>,
}
Represents a resource in the extension with metadata

Fields

uri: String

URI representing the resource location (e.g., “file:///path/to/file” or “str:///content”)

name: String

Name of the resource

title: Option<String>

Human-readable title of the resource

description: Option<String>

Optional description of the resource

mime_type: Option<String>

MIME type of the resource content (“text” or “blob”)

size: Option<u32>

The size of the raw resource content, in bytes (i.e., before base64 encoding or any tokenization), if known.

This can be used by Hosts to display file sizes and estimate context window us

icons: Option<Vec<Icon>>

Optional list of icons for the resource

meta: Option<Meta>

Optional additional metadata for this resource

Implementations

Source

impl RawResource

pub fn new(uri: impl Into<String>, name: impl Into<String>) -> Self

Creates a new Resource from a URI with explicit mime type

pub fn with_title(self, title: impl Into<String>) -> Self

Set the human-readable title.

pub fn with_description(self, description: impl Into<String>) -> Self

Set the description.

pub fn with_mime_type(self, mime_type: impl Into<String>) -> Self

Set the MIME type.

pub fn with_size(self, size: u32) -> Self

Set the size in bytes.

pub fn with_icons(self, icons: Vec<Icon>) -> Self

Set the icons.

pub fn with_meta(self, meta: Meta) -> Self

Set the metadata.