#[non_exhaustive]pub struct Request<M = String, P = JsonObject> {
pub method: M,
pub params: P,
pub extensions: Extensions,
}Expand description
Represents a JSON-RPC request with method, parameters, and extensions.
This is the core structure for all MCP requests, containing:
method: The name of the method being calledparams: The parameters for the methodextensions: Additional context data (similar to HTTP headers)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method: Mparams: Pextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate
Implementations