pub struct RequestNoParam<M = String> {
pub method: M,
pub extensions: Extensions,
}Fields
method: Mextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate