#[non_exhaustive]pub struct SubscriptionFilter {
pub tools_list_changed: Option<bool>,
pub prompts_list_changed: Option<bool>,
pub resources_list_changed: Option<bool>,
pub resource_subscriptions: Option<Vec<String>>,
}Expand description
Notification categories a client opts in to on a subscriptions/listen stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tools_list_changed: Option<bool>prompts_list_changed: Option<bool>resources_list_changed: Option<bool>resource_subscriptions: Option<Vec<String>>Implementations
Sourceimpl SubscriptionFilter
impl SubscriptionFilter
Sourcepub fn builder() -> SubscriptionFilterBuilder
pub fn builder() -> SubscriptionFilterBuilder
Create a builder for a subscription filter.
Sourcepub fn intersection(&self, other: &Self) -> Self
pub fn intersection(&self, other: &Self) -> Self
Return the subset present in both filters.
Sourcepub fn is_subset_of(&self, other: &Self) -> bool
pub fn is_subset_of(&self, other: &Self) -> bool
Return whether this filter accepts only notifications requested by other.
Sourcepub fn supported_by(&self, capabilities: &ServerCapabilities) -> Self
pub fn supported_by(&self, capabilities: &ServerCapabilities) -> Self
Return the requested notification types advertised by server capabilities.