#[non_exhaustive]pub struct ToolExecution {
pub task_support: Option<TaskSupport>,
}Expand description
Execution-related configuration for a tool.
This struct contains settings that control how a tool should be executed, including task support configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_support: Option<TaskSupport>Indicates whether this tool supports task-based invocation.
When not present or set to Forbidden, clients MUST NOT invoke this tool as a task.
When set to Optional, clients MAY invoke this tool as a task or normal call.
When set to Required, clients MUST invoke this tool as a task.
Implementations
Sourceimpl ToolExecution
impl ToolExecution
Sourcepub fn from_raw(task_support: Option<TaskSupport>) -> Self
pub fn from_raw(task_support: Option<TaskSupport>) -> Self
Create a ToolExecution from raw optional fields.
Sourcepub fn with_task_support(self, task_support: TaskSupport) -> Self
pub fn with_task_support(self, task_support: TaskSupport) -> Self
Set the task support mode.