pub struct ToolListChangedNotificationMethod;Trait Implementations
Sourceimpl Clone for ToolListChangedNotificationMethod
impl Clone for ToolListChangedNotificationMethod
Sourcefn clone(&self) -> ToolListChangedNotificationMethod
fn clone(&self) -> ToolListChangedNotificationMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ToolListChangedNotificationMethod
Sourceimpl Default for ToolListChangedNotificationMethod
impl Default for ToolListChangedNotificationMethod
Sourcefn default() -> ToolListChangedNotificationMethod
fn default() -> ToolListChangedNotificationMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ToolListChangedNotificationMethod
impl<'de> Deserialize<'de> for ToolListChangedNotificationMethod
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ToolListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ToolListChangedNotificationMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolListChangedNotificationMethod
Sourceimpl JsonSchema for ToolListChangedNotificationMethod
Available on crate feature schemars only.
impl JsonSchema for ToolListChangedNotificationMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolListChangedNotificationMethod
impl PartialEq for ToolListChangedNotificationMethod
Sourcefn eq(&self, other: &ToolListChangedNotificationMethod) -> bool
fn eq(&self, other: &ToolListChangedNotificationMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ToolListChangedNotificationMethod