pub struct UnsubscribeRequestMethod;Trait Implementations
Sourceimpl Clone for UnsubscribeRequestMethod
impl Clone for UnsubscribeRequestMethod
Sourcefn clone(&self) -> UnsubscribeRequestMethod
fn clone(&self) -> UnsubscribeRequestMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UnsubscribeRequestMethod
Sourceimpl Debug for UnsubscribeRequestMethod
impl Debug for UnsubscribeRequestMethod
Sourceimpl Default for UnsubscribeRequestMethod
impl Default for UnsubscribeRequestMethod
Sourcefn default() -> UnsubscribeRequestMethod
fn default() -> UnsubscribeRequestMethod
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UnsubscribeRequestMethod
impl<'de> Deserialize<'de> for UnsubscribeRequestMethod
Sourcefn deserialize<D>(deserializer: D) -> Result<UnsubscribeRequestMethod, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<UnsubscribeRequestMethod, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UnsubscribeRequestMethod
Sourceimpl JsonSchema for UnsubscribeRequestMethod
Available on crate feature schemars only.
impl JsonSchema for UnsubscribeRequestMethod
Available on crate feature
schemars only.Sourcefn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UnsubscribeRequestMethod
impl PartialEq for UnsubscribeRequestMethod
Sourcefn eq(&self, other: &UnsubscribeRequestMethod) -> bool
fn eq(&self, other: &UnsubscribeRequestMethod) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnsubscribeRequestMethod
impl Serialize for UnsubscribeRequestMethod
impl StructuralPartialEq for UnsubscribeRequestMethod