pub type ListResourcesRequest = RequestOptionalParam<ListResourcesRequestMethod, PaginatedRequestParams>;Expand description
Request to list all available resources from a server
Aliased Type
pub struct ListResourcesRequest {
pub method: ListResourcesRequestMethod,
pub params: Option<PaginatedRequestParams>,
pub extensions: Extensions,
}Fields
method: ListResourcesRequestMethodparams: Option<PaginatedRequestParams>extensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate