pub type PingRequest = RequestNoParam<PingRequestMethod>;Aliased Type
pub struct PingRequest {
pub method: PingRequestMethod,
pub extensions: Extensions,
}Fields
method: PingRequestMethodextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate