#[non_exhaustive]pub enum ServerInitializeError {
ExpectedInitializeRequest(Option<ClientJsonRpcMessage>),
ConnectionClosed(String),
UnexpectedInitializeResponse(ServerResult),
InitializeFailed(ErrorData),
TransportError {
error: DynamicTransportError,
context: Cow<'static, str>,
},
Cancelled,
}Available on crate feature
server and (crate features client or server) only.Expand description
It represents the error that may occur when serving the server.
if you want to handle the error, you can use serve_server_with_ct or serve_server with Result<RunningService<RoleServer, S>, ServerError>
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ExpectedInitializeRequest(Option<ClientJsonRpcMessage>)
ConnectionClosed(String)
UnexpectedInitializeResponse(ServerResult)
InitializeFailed(ErrorData)
TransportError
Cancelled
Implementations