#[non_exhaustive]pub struct RequestContext<R: ServiceRole> {
pub ct: CancellationToken,
pub id: RequestId,
pub meta: RequestMetaObject,
pub extensions: Extensions,
pub peer: Peer<R>,
}Available on crate features
client or server only.Expand description
Request execution context
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ct: CancellationTokenthis token will be cancelled when the CancelledNotification is received.
id: RequestIdmeta: RequestMetaObjectextensions: Extensionspeer: Peer<R>An interface to fetch the remote client or server
Implementations
Sourceimpl<R: ServiceRole> RequestContext<R>
impl<R: ServiceRole> RequestContext<R>
Sourceimpl RequestContext<RoleServer>
impl RequestContext<RoleServer>
Sourcepub fn protocol_version(&self) -> Option<ProtocolVersion>
Available on crate feature server only.
pub fn protocol_version(&self) -> Option<ProtocolVersion>
server only.The current request’s protocol version, falling back to legacy handshake state.
Sourcepub fn client_info(&self) -> Option<Implementation>
Available on crate feature server only.
pub fn client_info(&self) -> Option<Implementation>
server only.The current request’s client implementation, falling back only for legacy sessions.
Sourcepub fn client_capabilities(&self) -> Option<ClientCapabilities>
Available on crate feature server only.
pub fn client_capabilities(&self) -> Option<ClientCapabilities>
server only.The current request’s client capabilities, falling back only for legacy sessions.