pub struct ArgumentInfo {
pub name: String,
pub value: String,
}Fields
name: Stringvalue: StringTrait Implementations
Sourceimpl Clone for ArgumentInfo
impl Clone for ArgumentInfo
Sourcefn clone(&self) -> ArgumentInfo
fn clone(&self) -> ArgumentInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArgumentInfo
impl Debug for ArgumentInfo
Sourceimpl<'de> Deserialize<'de> for ArgumentInfo
impl<'de> Deserialize<'de> for ArgumentInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArgumentInfo
impl JsonSchema for ArgumentInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArgumentInfo
impl PartialEq for ArgumentInfo
Sourceimpl Serialize for ArgumentInfo
impl Serialize for ArgumentInfo
impl StructuralPartialEq for ArgumentInfo