#[non_exhaustive]pub struct CallToolRequestParams {
pub meta: Option<Meta>,
pub name: Cow<'static, str>,
pub arguments: Option<JsonObject>,
pub task: Option<JsonObject>,
}Expand description
Parameters for calling a tool provided by an MCP server.
Contains the tool name and optional arguments needed to execute the tool operation.
This implements TaskAugmentedRequestParamsMeta as tool calls can be
long-running and may benefit from task-based execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Meta>Protocol-level metadata for this request (SEP-1319)
name: Cow<'static, str>The name of the tool to call
arguments: Option<JsonObject>Arguments to pass to the tool (must match the tool’s input schema)
task: Option<JsonObject>Task metadata for async task management (SEP-1319)
Implementations
Sourceimpl CallToolRequestParams
impl CallToolRequestParams
Sourcepub fn new(name: impl Into<Cow<'static, str>>) -> Self
pub fn new(name: impl Into<Cow<'static, str>>) -> Self
Creates a new CallToolRequestParams with the given tool name.
Sourcepub fn with_arguments(self, arguments: JsonObject) -> Self
pub fn with_arguments(self, arguments: JsonObject) -> Self
Sets the arguments for this tool call.
Sourcepub fn with_task(self, task: JsonObject) -> Self
pub fn with_task(self, task: JsonObject) -> Self
Sets the task metadata for this tool call.