CreateMessageRequestParams

Struct CreateMessageRequestParams 

#[non_exhaustive]
pub struct CreateMessageRequestParams { pub meta: Option<RequestMetaObject>, pub messages: Vec<SamplingMessage>, pub model_preferences: Option<ModelPreferences>, pub system_prompt: Option<String>, pub include_context: Option<ContextInclusion>, pub temperature: Option<f32>, pub max_tokens: u32, pub stop_sequences: Option<Vec<String>>, pub metadata: Option<Value>, pub tools: Option<Vec<Tool>>, pub tool_choice: Option<ToolChoice>, }
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Parameters for creating a message through LLM sampling.

This structure contains all the necessary information for a client to generate an LLM response, including conversation history, model preferences, and generation parameters.

This implements TaskAugmentedRequestParamsMeta as sampling requests can be long-running and may benefit from task-based execution.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
meta: Option<RequestMetaObject>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Protocol-level metadata for this request (SEP-1319)

messages: Vec<SamplingMessage>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

The conversation history and current messages

model_preferences: Option<ModelPreferences>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Preferences for model selection and behavior

system_prompt: Option<String>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

System prompt to guide the modelโ€™s behavior

include_context: Option<ContextInclusion>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

How much context to include from MCP servers

temperature: Option<f32>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Temperature for controlling randomness (0.0 to 1.0)

max_tokens: u32
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Maximum number of tokens to generate

stop_sequences: Option<Vec<String>>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Sequences that should stop generation

metadata: Option<Value>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Additional metadata for the request

tools: Option<Vec<Tool>>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Tools available for the model to call (SEP-1577)

tool_choice: Option<ToolChoice>
๐Ÿ‘ŽDeprecated since 2.0.0:

Sampling is deprecated by SEP-2577 and will be removed in a future release. See https://github.com/modelcontextprotocol/modelcontextprotocol/pull/2577

Tool selection behavior (SEP-1577)

Implementations

Source

impl CreateMessageRequestParams

pub fn new(messages: Vec<SamplingMessage>, max_tokens: u32) -> Self

Create a new CreateMessageRequestParams with required fields.

pub fn with_model_preferences(self, model_preferences: ModelPreferences) -> Self

Set model preferences.

pub fn with_system_prompt(self, system_prompt: impl Into<String>) -> Self

Set system prompt.

pub fn with_include_context(self, include_context: ContextInclusion) -> Self

Set include context.

pub fn with_temperature(self, temperature: f32) -> Self

Set temperature.

pub fn with_stop_sequences(self, stop_sequences: Vec<String>) -> Self

Set stop sequences.

pub fn with_metadata(self, metadata: Value) -> Self

Set metadata.

pub fn with_tools(self, tools: Vec<Tool>) -> Self

Set tools.

pub fn with_tool_choice(self, tool_choice: ToolChoice) -> Self

Set tool choice.

pub fn validate(&self) -> Result<(), String>

Validate the sampling request parameters per SEP-1577 spec requirements.

Checks:

  • ToolUse content is only allowed in assistant messages
  • ToolResult content is only allowed in user messages
  • Messages with tool result content MUST NOT contain other content types
  • Every assistant ToolUse must be balanced with a corresponding user ToolResult