#[non_exhaustive]pub struct Notification<M = String, P = JsonObject> {
pub method: M,
pub params: P,
pub extensions: Extensions,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method: Mparams: Pextensions: Extensionsextensions will carry anything possible in the context, including the metadata
(RequestMetaObject for requests, NotificationMetaObject for notifications)
this is similar with the Extensions in http crate
Implementations