#[non_exhaustive]pub struct Prompt {
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub arguments: Option<Vec<PromptArgument>>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<Meta>,
}Expand description
A prompt that can be used to generate text from a model
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the prompt
title: Option<String>description: Option<String>Optional description of what the prompt does
arguments: Option<Vec<PromptArgument>>Optional arguments that can be passed to customize the prompt
icons: Option<Vec<Icon>>Optional list of icons for the prompt
meta: Option<Meta>Optional additional metadata for this prompt
Implementations
Sourceimpl Prompt
impl Prompt
Sourcepub fn new<N, D>(
name: N,
description: Option<D>,
arguments: Option<Vec<PromptArgument>>,
) -> Self
pub fn new<N, D>( name: N, description: Option<D>, arguments: Option<Vec<PromptArgument>>, ) -> Self
Create a new prompt with the given name, description and arguments
Sourcepub fn from_raw(
name: impl Into<String>,
description: Option<impl Into<String>>,
arguments: Option<Vec<PromptArgument>>,
) -> Self
pub fn from_raw( name: impl Into<String>, description: Option<impl Into<String>>, arguments: Option<Vec<PromptArgument>>, ) -> Self
Create a new prompt from raw fields (used by the macro)
Sourcepub fn with_title(self, title: impl Into<String>) -> Self
pub fn with_title(self, title: impl Into<String>) -> Self
Set the human-readable title
Sourcepub fn with_icons(self, icons: Vec<Icon>) -> Self
pub fn with_icons(self, icons: Vec<Icon>) -> Self
Set the icons