pub struct ProtocolVersion(/* private fields */);Expand description
Represents the MCP protocol version used for communication.
This ensures compatibility between clients and servers by specifying which version of the Model Context Protocol is being used.
Implementations
Sourceimpl ProtocolVersion
impl ProtocolVersion
pub const V_2026_07_28: Self
pub const V_2025_11_25: Self
pub const V_2025_06_18: Self
pub const V_2025_03_26: Self
pub const V_2024_11_05: Self
pub const LATEST: Self = Self::V_2025_11_25
Sourcepub const KNOWN_VERSIONS: &[Self]
pub const KNOWN_VERSIONS: &[Self]
All protocol versions known to this SDK.