pub type RootsListChangedNotification = NotificationNoParam<RootsListChangedNotificationMethod>;Aliased Type
pub struct RootsListChangedNotification {
pub method: RootsListChangedNotificationMethod,
pub extensions: Extensions,
}Fields
method: RootsListChangedNotificationMethodextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate