pub type ToolListChangedNotification = NotificationNoParam<ToolListChangedNotificationMethod>;Expand description
Notification sent when the list of available tools changes
Aliased Type
pub struct ToolListChangedNotification {
pub method: ToolListChangedNotificationMethod,
pub extensions: Extensions,
}Fields
method: ToolListChangedNotificationMethodextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate