Module service

Module service 

Available on crate features client or server only.

Macros

elicit_safeelicitation and server
Macro to mark types as safe for elicitation by verifying they generate object schemas.

Structs

AtomicU32Provider
NotificationContext
Request execution context
Peer
An interface to fetch the remote client or server
PeerRequestOptions
RequestContext
Request execution context
RequestHandle
A handle to a remote request
RoleClientclient
RoleServerserver
RunningService
RunningServiceCancellationToken
TowerHandlertower

Enums

ClientInitializeErrorclient
It represents the error that may occur when serving the client.
ElicitationErrorelicitation and server
Errors that can occur during typed elicitation operations
ElicitationModeserver
QuitReason
ServerInitializeErrorserver
It represents the error that may occur when serving the server.
ServiceError

Traits

DynServiceNon-local
ElicitationSafeelicitation and server
Marker trait to ensure that elicitation types generate object-type JSON schemas.
ProgressTokenProvider
RequestIdProvider
ServiceNon-local
ServiceExt
ServiceRole

Functions

serve_clientclient
serve_client_with_ctclient
serve_directly
Use this function to skip initialization process
serve_directly_with_ct
Use this function to skip initialization process
serve_serverserver
serve_server_with_ctserver

Type Aliases

AtomicU32ProgressTokenProvider
AtomicU32RequestIdProvider
ClientSinkserver
RxJsonRpcMessage
ServerSinkclient
TxJsonRpcMessage