Available on crate features
client or server only.Macros
- elicit_
safe elicitationandserver - Macro to mark types as safe for elicitation by verifying they generate object schemas.
Structs
- Atomic
U32Provider - Notification
Context - Request execution context
- Peer
- An interface to fetch the remote client or server
- Peer
Request Options - Request
Context - Request execution context
- Request
Handle - A handle to a remote request
- Role
Client client - Role
Server server - Running
Service - Running
Service Cancellation Token - Tower
Handler tower
Enums
- Client
Initialize Error client - It represents the error that may occur when serving the client.
- Elicitation
Error elicitationandserver - Errors that can occur during typed elicitation operations
- Elicitation
Mode server - Quit
Reason - Server
Initialize Error server - It represents the error that may occur when serving the server.
- Service
Error
Traits
- DynService
Non- local - Elicitation
Safe elicitationandserver - Marker trait to ensure that elicitation types generate object-type JSON schemas.
- Progress
Token Provider - Request
IdProvider - Service
Non- local - Service
Ext - Service
Role
Functions
- serve_
client client - serve_
client_ with_ ct client - serve_
directly - Use this function to skip initialization process
- serve_
directly_ with_ ct - Use this function to skip initialization process
- serve_
server server - serve_
server_ with_ ct server